import { createRoot } from 'react-dom/client'
import './index.css'
import './styles/dashboard.css'
import './styles/detail.css'
import App from './App.jsx'

createRoot(document.getElementById('root')).render(
  <App />,
)
